@@ -3,7 +3,7 @@ package Log::Dispatch::Output;
 use strict;
 use warnings;
 
-our $VERSION = '2.54';
+our $VERSION = '2.56';
 
 use Log::Dispatch;
 
@@ -34,6 +34,7 @@ sub log {
 
     return unless $self->_should_log( $p{level} );
 
+    local $!;
     $p{message} = $self->_apply_callbacks(%p)
         if $self->{callbacks};
 
@@ -172,13 +173,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Log::Dispatch::Output - Base class for all Log::Dispatch::* objects
 
 =head1 VERSION
 
-version 2.54
+version 2.56
 
 =head1 SYNOPSIS
 
@@ -290,11 +293,18 @@ set. Please make sure to use the C<_basic_init> method as described above.
 The actual logging implementation should be done in a C<log_message>
 method that you write. B<Do not override C<log>!>.
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|http://rt.cpan.org/Public/Dist/Display.html?Name=Log-Dispatch>
+(or L<bug-log-dispatch@rt.cpan.org|mailto:bug-log-dispatch@rt.cpan.org>).
+
+I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is Copyright (c) 2016 by Dave Rolsky.
 
